pub struct OrganizationMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on organization resources.
It is not used directly, but through the PolicyAnalyzer hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_policyanalyzer1 as policyanalyzer1;
use policyanalyzer1::{PolicyAnalyzer, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = PolicyAnalyzer::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `locations_activity_types_activities_query(...)`
// to build up your call.
let rb = hub.organizations();Implementations
Sourceimpl<'a, C> OrganizationMethods<'a, C>
impl<'a, C> OrganizationMethods<'a, C>
Sourcepub fn locations_activity_types_activities_query(
&self,
parent: &str,
) -> OrganizationLocationActivityTypeActivityQueryCall<'a, C>
pub fn locations_activity_types_activities_query( &self, parent: &str, ) -> OrganizationLocationActivityTypeActivityQueryCall<'a, C>
Create a builder to help you perform the following task:
Queries policy activities on Google Cloud resources.
Arguments
parent- Required. The container resource on which to execute the request. Acceptable formats:projects/[PROJECT_ID|PROJECT_NUMBER]/locations/[LOCATION]/activityTypes/[ACTIVITY_TYPE]LOCATION here refers to Google Cloud Locations: https://cloud.google.com/about/locations/